#!/bin/sh
# Execute in the root of the project to get the version

[ $# -gt 0 ] && PACKAGE_NAME=$1
PACKAGE_NAME=${PACKAGE_NAME:-cdimgtools}
DEF_VER="unknown_version"

LF='
'

# First try git-describe, then see if there is a VERSION file (included in
# release tarballs), then see if the project directory matches the project
# name, then use the default.
if test -d .git -o -f .git &&
	VN=$(git describe --abbrev=7 --match "version/*" --tags HEAD --always 2>/dev/null) &&
	case "$VN" in
	(*$LF*) false ;;
	(version/*)
		git update-index -q --refresh
		test -z "$(git diff-index --name-only HEAD --)" ||
		VN="$VN.dirty" ;;
	esac
then
	VN=$(echo "$VN" | sed -e 's#^\(ver\|VER\)[a-zA-Z]*/##' -e 's/-/+/' -e 's/-/_/')
		# <tag>+<num-of-commits>_g<hash>.dirty
elif test -f VERSION && test -s VERSION
then
	VN=$(cat VERSION) || VN="$DEF_VER"
elif VN=$(pwd -P | sed -e 's#^.*/##') &&
    test x"$VN" != x"${VN#"$PACKAGE_NAME-"}"
then
    VN=${VN#"$PACKAGE_NAME-"}
else
	VN="$DEF_VER"
fi

echo -n "$VN"
